# CoreX config - environment

This package provides an implementation of the CoreX config interface for environment.

## Installation
~~~bash
pip install corex-config-environment
~~~

## Usage
~~~python
from corex_config_environment.handler import EnvironmentHandler
handler = EnvironmentHandler()
handler.example_method()
~~~

## License
This package is licensed under the MIT License. See [LICENSE](../LICENSE) for details.
